import { Registry } from "prom-client";
/**
 * Capture fields from the default package.json
 */
export interface PackageType {
    name: string;
    version: string;
    description: string;
    author: string;
    license: string;
    dependencies: {
        [packageName: string]: string;
    };
    devDependencies: {
        [packageName: string]: string;
    };
}
export interface MindsEyeConfiguration {
    /**
     * Where package.json is located
     */
    packageJsonPath?: string;
    /**
     * You can also pass in the package.json buffer directly if you loaded it.
     */
    packageJson?: string;
    /**
     * prefix for where all the node modules are.
     * Will use `./node_modules` if unspecified
     */
    nodeModulesPath?: string;
    /**
     * Please pass in the register from the default import!
     */
    registers?: Registry[];
    /**
     * Which port to run the exporter on, defaults to 9991
     * Metrics are available on localhost:9991/metrics
     */
    port?: number;
    /**
     * Logs to console.err if true
     */
    reportMissingPackageJson?: boolean;
    /**
     * If you are managing your own exporter, set this to false
     * By default it will run a separate express app on port 9991
     */
    runExpress?: boolean;
}
/**
 * Read current directory's package.json, and read its dependencies, and display them
 * in a prometheus exporter on port 9991
 *
 * Useful to put into legacy applications to have dependencies available in prometheus
 * and visualize via grafana
 *
 * @param config
 */
export declare function collectPackageInfo(config: MindsEyeConfiguration): boolean;
