"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var prom_client_1 = require("prom-client");
var fs_1 = require("fs");
var express_1 = __importDefault(require("express"));
function getIndividualPackageVersions(config, packageName) {
    var version = undefined;
    try {
        var path = config.nodeModulesPath
            ? "" + config.nodeModulesPath + packageName + "/package.json"
            : "./node_modules/" + packageName + "/package.json";
        var loadedPackageJson = JSON.parse(fs_1.readFileSync(path).toString("utf-8"));
        if (loadedPackageJson.version) {
            version = loadedPackageJson.version;
        }
    }
    catch (err) {
        if (config.reportMissingPackageJson) {
            console.error("Cannot locate package info for sub-packages " + packageName + ": " + err.message);
        }
    }
    return version;
}
/**
 * Read current directory's package.json, and read its dependencies, and display them
 * in a prometheus exporter on port 9991
 *
 * Useful to put into legacy applications to have dependencies available in prometheus
 * and visualize via grafana
 *
 * @param config
 */
function collectPackageInfo(config) {
    var localRegisters = [prom_client_1.register];
    if (config.registers) {
        localRegisters = config.registers;
    }
    else if (config.port) {
        // When port is specified, use a new Register
        localRegisters = [new prom_client_1.Registry()];
    }
    var packageCounter = new prom_client_1.Counter({
        name: "npm_packages_installed",
        help: "npm packages installed for this project",
        labelNames: ["package_type", "package_name", "package_version"],
        registers: localRegisters
    });
    var packageJson = undefined;
    if (config.packageJson) {
        packageJson = JSON.parse(config.packageJson);
    }
    else if (config.packageJsonPath) {
        packageJson = JSON.parse(fs_1.readFileSync(config.packageJsonPath).toString("utf-8"));
    }
    else {
        packageJson = JSON.parse(fs_1.readFileSync("./package.json").toString("utf-8"));
    }
    if (packageJson !== undefined) {
        for (var depPackageName in packageJson.devDependencies) {
            packageCounter.inc({
                package_type: "dev-dep",
                package_name: depPackageName,
                package_version: getIndividualPackageVersions(config, depPackageName) ||
                    packageJson.devDependencies[depPackageName]
            });
        }
        for (var packageName in packageJson.dependencies) {
            packageCounter.inc({
                package_type: "dep",
                package_name: packageName,
                package_version: getIndividualPackageVersions(config, packageName) ||
                    packageJson.dependencies[packageName]
            });
        }
        // Setup express.
        if (config.runExpress !== false) {
            var metricServer = express_1.default();
            metricServer.get("/metrics", function (req, res) {
                res.send(prom_client_1.Registry.merge(localRegisters).metrics());
            });
            metricServer.listen(config.port || 9991, function () {
                return console.log("MindsEye listening on port " + (config.port || 9991) + " /metrics");
            });
        }
        return true;
    }
    return false;
}
exports.collectPackageInfo = collectPackageInfo;
